django\_sorcery.management package
==================================

.. automodule:: django_sorcery.management
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   django_sorcery.management.commands

Submodules
----------

.. toctree::
   :maxdepth: 4

   django_sorcery.management.alembic
   django_sorcery.management.base
